@@ -246,7 +246,7 @@ void tl_timeout_changed(t_tl *tl)
 }
 
 static
-void tl_timeout_add_options(t_tl *tl)
+void tl_timeout_create_options(t_tl *tl)
 {
 	GtkWidget *h;
 	GtkWidget *c1;
@@ -937,7 +937,7 @@ my_create_icon_option(GtkSizeGroup *sg, char const *which)
 }
 
 static void
-tl_add_options(Control *control, GtkContainer *container, GtkWidget *done)
+tl_create_options(Control *control, GtkContainer *container, GtkWidget *done)
 {
 	t_tl		*tl;
 	GtkWidget 	*vbox, *vbox2, *vbox3;
@@ -977,7 +977,7 @@ tl_add_options(Control *control, GtkContainer *container, GtkWidget *done)
 	gtk_container_add(GTK_CONTAINER(container), GTK_WIDGET(vbox));
 	
 	tl->settings_c = GTK_CONTAINER(vbox);
-	tl_timeout_add_options (tl);
+	tl_timeout_create_options (tl);
 
 
 	tl_fill_options(tl);
@@ -1096,7 +1096,7 @@ xfce_control_class_init (ControlClass * cc)
     cc->write_config = tl_write_config;
     cc->attach_callback = tl_attach_callback;
     
-    cc->add_options = (gpointer) tl_add_options;
+    cc->create_options = (gpointer) tl_create_options;
 
     cc->set_theme = tl_set_theme;
 
